function bin_mass(min_orbit, max_orbit, datafrom, saveto)

% Written by James Rehberger 3/4/2011
%Takes in a minimum orbit, a maximum orbit and two directories. It searches 
%the first directory for data from the minimum orbit, processes the data, 
%and then loops incrementing up the orbit range until it reaches the 
%maximum orbit. If the orbit does not exist it simply skips that orbit for 
%the next one. The binned root mean  square and the number of variables in 
%each bin are extracted from the files. It then produces an accurate 
%balanced bin model of all the data from the orbits in the range based on 
%the number of datapoints in each bin for each orbit. Finally it saves the 
%new bin mass data into the second directory.


%Orbit data has binned orbit data, number of datapoints per bin, and the
%root mean square per bin
smallerdata = datafrom;

%Creates empty arrays the length of the total number of bins to make future
%parts of the function run faster
total_num = zeros(4001,1);
numerator = zeros(4001,1);
denominator = zeros(4001,1);

%Looks for orbit files with the indicated string and number in its name,
%incrementing the number after the file has been found. If the file is not
%there, it skips that number. If the file is there, continues on to mass
%bin the data inside
for i = min_orbit:max_orbit
filename = strcat(smallerdata, 'Single_Orbit_fa_k0_0', int2str(i), '.mat');

if(~(exist(filename,'file') == 2))
    continue
end

load(filename)

%The file thetvec was accidentally saved as an array in process_orbit2,
%this changes it to a column
thetvec = thetvec';

%Saves the withdrawn data into a matrix and organizes the rows by the theta
%value
small_matrix = [thetvec, rmse, num];
small_matrix = sortrows(small_matrix);

 theta=-20:.01:20;
 k=0;
 
 %Inputs the previously made matrix and finds the root mean square of its
 %data and the data already inputted from previous orbits. Ensures accurate
 %results by incorperating the number of datapoints per bin into the
 %equasion to determine the influence of the inputted data
 for thet=theta
     k=k+1;
     ind=find(small_matrix(:,1)>= thet & small_matrix(:,1)<(thet+.01), 1);
     if ~isempty(ind)
         if ~isnan(small_matrix(k,2))
        numerator(k,1) = numerator(k,1) + (small_matrix(k,2)^2 * small_matrix(k,3));
        denominator(k,1) = denominator(k,1) + small_matrix(k,3);
        total_num(k,1) = denominator(k,1)+total_num(k,1) ;
             else
         numerator(k,1) = numerator(k,1);
         total_num(k,1)= total_num(k,1);
         end
     end
 end
end
 big_rmse = sqrt(numerator ./ denominator);
 
 %Stores and saves the mass data into a file that has the orbit range in
 %its name
 mass_orbit_data = [theta', big_rmse, total_num];
 save_path = strcat(saveto, 'BigOrbits_', int2str(min_orbit), int2str(max_orbit));
 save(save_path, 'mass_orbit_data');
 
%Plots the electric field vs. theta
figure;
plot(mass_orbit_data(:,1), mass_orbit_data(:,2));
xlabel('theta');
ylabel('mV/m');

header = strcat(int2str(min_orbit), ' to ', int2str(max_orbit));
title(header);

savepath2 = strcat(save_path, '.fig');
saveas(gcf, savepath2);
 
end