function [geo_result] = dcs2togeo(dcs_xyz,b_model,spin_axis)
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This function is designed to convert the electric field data from the
% DCS2 coordinate system to the GEI or GEO coordinate system (depending on
% what coordinate system the inputted b_model data is in).
%
% Inputs are the X, Y, and Z axis values for the electric field (dcs_xyz),
% the B Model data (b_model, in GEI or GEO), and the spin axis data
% (spin_axis). All three sets of data must have overlapping times.
%
% The output of this function is the dcs_xyz input convert to either the
% GEI or GEO coordinate system.

norm_sa = normr(spin_axis);
norm_mag = normr(b_model);

spBp = cross(norm_sa,norm_mag);
norm_spBp = normr(spBp);

spB = cross(norm_spBp,norm_sa);
norm_spB = normr(spB);

tmp1 = bsxfun(@times, norm_spBp, dcs_xyz(:,1));
tmp2 = bsxfun(@times, norm_sa, dcs_xyz(:,2));
tmp3 = bsxfun(@times, norm_spB, dcs_xyz(:,3));
clearvars norm_spBp norm_sa norm_spB dcs_xyz

geo_x = tmp1(:,1) + tmp2(:,1) + tmp3(:,1);
geo_y = tmp1(:,2) + tmp2(:,2) + tmp3(:,2);
geo_z = tmp1(:,3) + tmp2(:,3) + tmp3(:,3);
clearvars tmp1 tmp2 tmp3

geo_result = [geo_x, geo_y, geo_z];

end
