function [ unix_time_matrix ] = kp_to_unixtime(directory, kp_index_start, kp_index_end )
%
%   Author: Steven Chen
%           March 2, 2011
%
%   INPUT:
%       Input containing the range of Kp values (which is technically
%       really Ap values) for which to perform this operation on.
%       
%
%   OUPUT:
%       Outputs a unix-time matrix that contains the starting times for
%       all values within the Kp index ranges.
%                       

%   Loads the matlab file with the corresponding dates and kp_index values

kp_struct = load(strcat(directory, 'KP_1996_2010.mat'));

[I J] = find(kp_struct.kp(:,:) >= kp_index_start & kp_struct.kp(:,:) <= kp_index_end);

%   Make room for the final output matrix
unix_time_matrix = zeros(length(J),3);

%   Converts the kp_index into the right year/month/day
unix_time_matrix(:,1) = uint32(kp_struct.datesKP(:,J)/10000);
unix_time_matrix(:,2) = uint32(kp_struct.datesKP(:,J)' - unix_time_matrix(:,1)*10000)/100;
unix_time_matrix(:,3) = uint32(kp_struct.datesKP(:,J)' - unix_time_matrix(:,1)*10000 - unix_time_matrix(:,2)*100);

%   Changes it to datenum for compatibility in possible later revisions
unix_time_matrix(:,1) = datenum(unix_time_matrix(:,1),unix_time_matrix(:,2),unix_time_matrix(:,3));

%   Clears the month and day columns, already done using them
unix_time_matrix(:,2:3) = [];

%   Changes from matlab serial time to unix time
unix_time_matrix(:,1) = mat2unixtime(unix_time_matrix);

%   Based on the row number changes the time accordingly.
unix_time_matrix(:,1) = unix_time_matrix(:,1) + (I(:,1) - 1) * 10800;

end

