function [output_data_gei, output_data_geo] = process_flux(orb_data, ef_data, mag_data, ees_data, ies_data, axis_data, orbitname, processeddata)
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This is a top-level m-file which calls multiple other functions and
% m-files in order to process summary CDF files to find the Poynting
% vector and plot relevant quantities

    %% Load data and assign to correct matrices
    
   [field_matrix, pos_matrix, sa_matrix, ees_matrix, ies_matrix] = load_data(orb_data, ef_data, mag_data, ees_data, ies_data, axis_data);
    if (isempty(field_matrix) || isempty(pos_matrix) || isempty(ees_matrix) || isempty(ies_matrix) || isempty(sa_matrix))
        return;
    end
  clearvars orb_data ef_data mag_data ees_data ies_data sa_data axis_data

    
    %% Calculate the Kinetic Energy Flux
    
    % To be completed by future project groups.
    
    
    %% Calculate the Poynting Flux
    
    % Assign permiability of free space 
    u_0 = 4*pi*1e-7;
    
    % H (delta-B)(GEI and GEO)
    H_gei = field_matrix(:,8:10);
    H_geo = field_matrix(:,14:16);
    
    % E (Electric Field)(GEI and GEO)
    E_gei = field_matrix(:,2:4);
    E_geo = field_matrix(:,5:7);
    
    % Find unit vector of B field (GEI and GEO) with latitude in degrees
    b_uv_gei = normr(pos_matrix(:,17:19));
    b_uv_geo = normr(pos_matrix(:,20:22));
    
    
    %%%%% Calculate the Poynting flux in GEI %%%%
    cross_poynt_gei_tmp = cross(E_gei,H_gei);
	
	% If the satellite is in the southern hemisphere, sign swith the Poynting flux.
    % This is to use the Poynting vector that points down the B-Field
	cross_poynt_gei_tmp(pos_matrix(:,15) < 0,:) = -cross_poynt_gei_tmp(pos_matrix(:,15) < 0,:);
    
    % Take the dot product of the poynting flux and the unit vector of B
    dot_poynt_gei_tmp = bsxfun(@times, cross_poynt_gei_tmp, b_uv_gei);
    dot_poynt_gei_tmp = dot_poynt_gei_tmp(:,1) + dot_poynt_gei_tmp(:,2) + dot_poynt_gei_tmp(:,3);
    
    % Divide by the permiability of free space
    poynt_gei = dot_poynt_gei_tmp/u_0;
    clearvars cross_poynt_gei_tmp dot_poynt_gei_tmp b_uv_gei H_gei
        
    
    %%%%% Calculate the Poynting flux in GEO %%%%
    cross_poynt_geo_tmp = cross(E_geo,H_geo);
	
    % If the satellite is in the southern hemisphere, sign swith the Poynting flux.
    % This is to use the Poynting vector that points down the B-Field
    cross_poynt_geo_tmp(pos_matrix(:,15) < 0,:) = -cross_poynt_geo_tmp(pos_matrix(:,15) < 0,:);
	
    % Take the dot product of the poynting flux and the unit vector of B
    dot_poynt_geo_tmp = bsxfun(@times, cross_poynt_geo_tmp, b_uv_geo);
    dot_poynt_geo_tmp = dot_poynt_geo_tmp(:,1) + dot_poynt_geo_tmp(:,2) + dot_poynt_geo_tmp(:,3);
    
    % Divide by the permeability of free space
    poynt_geo = dot_poynt_geo_tmp/u_0;     
    clearvars cross_poynt_geo_tmp dot_poynt_geo_tmp b_uv_geo H_geo pfs
    
    
    %%%%% Map the Poynting Flux to 100 km %%%%
    % Calculate the ration to map the poynting flux to 100 km
    b_mag_100 = sqrt(pos_matrix(:,25).^2 + pos_matrix(:,26).^2 + pos_matrix(:,27).^2);
    b_mag_alt = sqrt(pos_matrix(:,17).^2 + pos_matrix(:,18).^2 + pos_matrix(:,19).^2);
    mapping_ratio = b_mag_100 ./ b_mag_alt;
    
    % Map the poynting flux values to 100 km
    poynt_gei = mapping_ratio .* poynt_gei;
    poynt_geo = mapping_ratio .* poynt_geo;
    
    
    %% Create Final Output Matrix and Save
        
    if (exist(strcat(processeddata,'PoyntingFlux\',orbitname), 'file') ~= 7)
        mkdir(strcat(processeddata,'PoyntingFlux\',orbitname));
    end
       
    output_data_gei = [field_matrix(:,1), pos_matrix(:,14:16), field_matrix(:,8:13), E_gei, poynt_gei];
    %output_data_gei(:,1)       = unix time
    %output_data_gei(:,2:4)     = alt,lat,long
    %output_data_gei(:,5:7)     = delta-B x,y,z (GEI)
    %output_data_gei(:,8:10)    = B field x,y,z (GEI)
    %output_data_gei(:,11:13)   = E field x,y,z (GEI)
    %output_data_gei(:,14)      = Poynting Flux (GEI)
   save(strcat(processeddata,'\PoyntingFlux\',orbitname,'\',orbitname,'_gei'),'output_data_gei');

     output_data_geo = [field_matrix(:,1), pos_matrix(:,14:16), field_matrix(:,14:19), E_geo, poynt_geo, pos_matrix(:,24), pos_matrix(:,23)];
    %output_data_geo(:,1)       = unix time
    %output_data_geo(:,2:4)     = alt,lat,long
    %output_data_geo(:,5:7)     = delta-B x,y,z (GEO)
    %output_data_geo(:,8:10)    = B field x,y,z (GEO)
    %output_data_geo(:,11:13)   = E field x,y,z (GEO)
    %output_data_geo(:,14)      = Poynting Flux (GEO)
    %output_data_geo(:,15)      = magnetic local time (MLT)
    %output_data_geo(:,16)      = invariant latitude (ILAT GEO)
   save(strcat(processeddata,'\PoyntingFlux\',orbitname,'\',orbitname,'_geo'),'output_data_geo');   
    
end

